import React, { Suspense, lazy } from "react";
import { Switch, Route, useLocation } from "wouter";
import { QueryClientProvider } from "@tanstack/react-query";
import { queryClient } from "./lib/queryClient";
import { Toaster } from "@/components/ui/toaster";
import { HelmetProvider, Helmet } from 'react-helmet-async';
import { ErrorBoundary, FallbackProps } from 'react-error-boundary';
import Navbar from "@/components/layout/navbar";
import Footer from "@/components/layout/footer";
import ScrollToTop from "@/components/ScrollToTop";
import { useAuth } from "@/lib/auth";
import { DeviceDetector } from "@/components/mobile/DeviceDetector";

// Lazy loaded components
const LoadingSpinner = () => (
  <div className="flex items-center justify-center min-h-[60vh]">
    <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-primary"></div>
  </div>
);

const ErrorFallback = ({ error, resetErrorBoundary }: FallbackProps) => (
  <div className="flex flex-col items-center justify-center min-h-[60vh] p-4 text-center">
    <h2 className="text-2xl font-bold text-gray-900 mb-4">Something went wrong</h2>
    <p className="text-gray-600 mb-4">{error.message}</p>
    <button
      onClick={resetErrorBoundary}
      className="px-4 py-2 bg-primary text-white rounded-md hover:bg-primary/90 transition-colors"
    >
      Try again
    </button>
  </div>
);

// Lazy load all pages
const Home = lazy(() => import("@/pages/home-ai-visual"));
const Services = lazy(() => import("@/pages/services"));
const Pricing = lazy(() => import("@/pages/pricing-updated"));
const Contact = lazy(() => import("@/pages/contact-fixed"));
const Analytics = lazy(() => import("@/pages/analytics"));
const RecruitmentCalculator = lazy(() => import("@/pages/tools/recruitment-calculator"));
const CareerPath = lazy(() => import("@/pages/tools/career-path"));
const PDFViewer = lazy(() => import("@/pages/tools/pdf-viewer"));
const WorkforcePlanning = lazy(() => import("@/pages/tools/workforce-planning"));
const CompensationBenchmarking = lazy(() => import("@/pages/tools/compensation-benchmarking"));
const Login = lazy(() => import("@/pages/login"));
const NotFound = lazy(() => import("@/pages/not-found"));
const Terms = lazy(() => import("@/pages/legal/terms"));
const Privacy = lazy(() => import("@/pages/legal/privacy"));
const Cookies = lazy(() => import("@/pages/legal/cookies"));
const InquiriesAdmin = lazy(() => import("@/pages/admin/inquiries"));
const AdminDashboard = lazy(() => import("@/pages/admin/dashboard"));
const AdminSettings = lazy(() => import("@/pages/admin/settings"));
const About = lazy(() => import("@/pages/about"));
const TeamStructureGenerator = lazy(() => import("@/pages/tools/team-structure-generator"));
const FAQ = lazy(() => import("@/pages/faq"));
const Careers = lazy(() => import("@/pages/careers"));
const Jobs = lazy(() => import("@/pages/jobs"));
const AdminLayout = lazy(() => import("@/components/layout/admin-layout"));
const HRHealthCheck = lazy(() => import("@/pages/tools/hr-health-check"));
const Resources = lazy(() => import("@/pages/resources-fixed"));
const QRCode = lazy(() => import("@/pages/qrcode"));


function ProtectedRoute({ component: Component, ...rest }: { component: React.ComponentType }) {
  const { isAuthenticated } = useAuth();
  const [, setLocation] = useLocation();

  React.useEffect(() => {
    if (!isAuthenticated) {
      setLocation('/login');
    }
  }, [isAuthenticated, setLocation]);

  if (!isAuthenticated) {
    return null;
  }

  return (
    <Suspense fallback={<LoadingSpinner />}>
      <AdminLayout>
        <Component {...rest} />
      </AdminLayout>
    </Suspense>
  );
}

function Router() {
  return (
    <div className="min-h-screen flex flex-col">
      <Helmet>
        <title>TalentForge360™ - AI-Driven Talent Management Platform</title>
        <meta name="description" content="Advanced AI-powered talent management platform for startups and small businesses. Optimize your workforce with intelligent assessment and planning tools."/>
        <meta name="keywords" content="talent management, AI recruitment, workforce planning, HR technology"/>
        <meta property="og:title" content="TalentForge360™ - AI-Driven Talent Management Platform"/>
        <meta property="og:description" content="Advanced AI-powered talent management platform for startups and small businesses. Optimize your workforce with intelligent assessment and planning tools."/>
        <meta property="og:type" content="website"/>
        <meta property="og:url" content={`https://talentforge360.replit.app${useLocation()[0]}`}/>
        <meta name="twitter:card" content="summary_large_image"/>
        <meta name="twitter:title" content="TalentForge360™ - AI-Driven Talent Management Platform"/>
        <meta name="twitter:description" content="Advanced AI-powered talent management platform for startups and small businesses. Optimize your workforce with intelligent assessment and planning tools."/>
        <link rel="canonical" href={`https://talentforge360.replit.app${useLocation()[0]}`}/>
      </Helmet>
      <ScrollToTop />
      <Navbar />

      <main className="flex-grow pt-16">
        <ErrorBoundary FallbackComponent={ErrorFallback}>
          <Suspense fallback={<LoadingSpinner />}>
            <Switch>
              {/* For wouter, use more specific routes first, then less specific routes */}
              {/* Tools - Public Calculators */}
              <Route path="/tools/recruitment-calculator" component={RecruitmentCalculator} />
              <Route path="/tools/team-structure" component={TeamStructureGenerator} />
              <Route path="/tools/career-path" component={CareerPath} />
              <Route path="/tools/workforce-planning" component={WorkforcePlanning} />
              <Route path="/tools/hr-health-check" component={HRHealthCheck} />
              <Route path="/tools/compensation-benchmarking" component={CompensationBenchmarking} />

              {/* Admin Routes - More specific first */}
              <Route path="/admin/dashboard">
                <ProtectedRoute component={AdminDashboard} />
              </Route>
              <Route path="/admin/inquiries">
                <ProtectedRoute component={InquiriesAdmin} />
              </Route>
              <Route path="/admin/settings">
                <ProtectedRoute component={AdminSettings} />
              </Route>
              <Route path="/admin/analytics">
                <ProtectedRoute component={Analytics} />
              </Route>
              <Route path="/admin/tools/pdf-viewer">
                <ProtectedRoute component={PDFViewer} />
              </Route>
              <Route path="/admin">
                <ProtectedRoute component={AdminDashboard} />
              </Route>

              {/* Legal Routes */}
              <Route path="/legal/terms" component={Terms} />
              <Route path="/legal/privacy" component={Privacy} />
              <Route path="/legal/cookies" component={Cookies} />
              
              {/* Main Routes - Less specific last */}
              <Route path="/about" component={About} />
              <Route path="/login" component={Login} />
              <Route path="/services" component={Services} />
              <Route path="/pricing" component={Pricing} />
              <Route path="/contact" component={Contact} />
              <Route path="/careers" component={Careers} />
              <Route path="/jobs" component={Jobs} />
              <Route path="/faq" component={FAQ} />
              <Route path="/resources" component={Resources} />
              <Route path="/qrcode" component={QRCode} />
              <Route path="/" component={Home} />

              {/* 404 route - This catches all undefined routes */}
              <Route component={NotFound} />
            </Switch>
          </Suspense>
        </ErrorBoundary>
      </main>
      <Footer />
    </div>
  );
}

function App() {
  // Check if we're in a browser environment
  const isBrowser = typeof window !== 'undefined';
  
  return (
    <QueryClientProvider client={queryClient}>
      <HelmetProvider>
        {isBrowser ? (
          // Only render components that use browser APIs when in browser environment
          <DeviceDetector>
            <Router />
            <Toaster />
          </DeviceDetector>
        ) : (
          // Simple server-side rendering fallback
          <Router />
        )}
      </HelmetProvider>
    </QueryClientProvider>
  );
}

export default App;